pub struct RpmbGetDeviceInfoResponse {
pub info: DeviceInfo,
}Fields
info: DeviceInfoTrait Implementations
Sourceimpl Clone for RpmbGetDeviceInfoResponse
impl Clone for RpmbGetDeviceInfoResponse
Sourcefn clone(&self) -> RpmbGetDeviceInfoResponse
fn clone(&self) -> RpmbGetDeviceInfoResponse
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for RpmbGetDeviceInfoResponse
impl Debug for RpmbGetDeviceInfoResponse
Sourceimpl<'a, ___E> Encode<RpmbGetDeviceInfoResponse<'static>, ___E> for &'a RpmbGetDeviceInfoResponsewhere
___E: InternalHandleEncoder + Encoder + ?Sized,
impl<'a, ___E> Encode<RpmbGetDeviceInfoResponse<'static>, ___E> for &'a RpmbGetDeviceInfoResponsewhere
___E: InternalHandleEncoder + Encoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<RpmbGetDeviceInfoResponse<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<RpmbGetDeviceInfoResponse<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<RpmbGetDeviceInfoResponse<'static>, ___E> for RpmbGetDeviceInfoResponsewhere
___E: InternalHandleEncoder + Encoder + ?Sized,
impl<___E> Encode<RpmbGetDeviceInfoResponse<'static>, ___E> for RpmbGetDeviceInfoResponsewhere
___E: InternalHandleEncoder + Encoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<RpmbGetDeviceInfoResponse<'static>>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<RpmbGetDeviceInfoResponse<'static>>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<'a, ___E> EncodeOption<Box<'static, RpmbGetDeviceInfoResponse<'static>>, ___E> for &'a RpmbGetDeviceInfoResponsewhere
___E: Encoder + ?Sized,
&'a RpmbGetDeviceInfoResponse: Encode<RpmbGetDeviceInfoResponse<'static>, ___E>,
impl<'a, ___E> EncodeOption<Box<'static, RpmbGetDeviceInfoResponse<'static>>, ___E> for &'a RpmbGetDeviceInfoResponsewhere
___E: Encoder + ?Sized,
&'a RpmbGetDeviceInfoResponse: Encode<RpmbGetDeviceInfoResponse<'static>, ___E>,
Sourcefn encode_option(
this: Option<&'a RpmbGetDeviceInfoResponse>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, RpmbGetDeviceInfoResponse<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<&'a RpmbGetDeviceInfoResponse>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, RpmbGetDeviceInfoResponse<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, RpmbGetDeviceInfoResponse<'static>>, ___E> for RpmbGetDeviceInfoResponsewhere
___E: Encoder + ?Sized,
RpmbGetDeviceInfoResponse: Encode<RpmbGetDeviceInfoResponse<'static>, ___E>,
impl<___E> EncodeOption<Box<'static, RpmbGetDeviceInfoResponse<'static>>, ___E> for RpmbGetDeviceInfoResponsewhere
___E: Encoder + ?Sized,
RpmbGetDeviceInfoResponse: Encode<RpmbGetDeviceInfoResponse<'static>, ___E>,
Sourcefn encode_option(
this: Option<RpmbGetDeviceInfoResponse>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, RpmbGetDeviceInfoResponse<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<RpmbGetDeviceInfoResponse>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, RpmbGetDeviceInfoResponse<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<'de> FromWire<RpmbGetDeviceInfoResponse<'de>> for RpmbGetDeviceInfoResponse
impl<'de> FromWire<RpmbGetDeviceInfoResponse<'de>> for RpmbGetDeviceInfoResponse
Sourcefn from_wire(wire: RpmbGetDeviceInfoResponse<'de>) -> RpmbGetDeviceInfoResponse
fn from_wire(wire: RpmbGetDeviceInfoResponse<'de>) -> RpmbGetDeviceInfoResponse
Converts the given owned value to this type.
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
const COPY_OPTIMIZATION: CopyOptimization<W, Self> = _
Sourceimpl<'de> FromWireRef<RpmbGetDeviceInfoResponse<'de>> for RpmbGetDeviceInfoResponse
impl<'de> FromWireRef<RpmbGetDeviceInfoResponse<'de>> for RpmbGetDeviceInfoResponse
Sourcefn from_wire_ref(
wire: &RpmbGetDeviceInfoResponse<'de>,
) -> RpmbGetDeviceInfoResponse
fn from_wire_ref( wire: &RpmbGetDeviceInfoResponse<'de>, ) -> RpmbGetDeviceInfoResponse
Converts the given reference to this type.
Sourceimpl Hash for RpmbGetDeviceInfoResponse
impl Hash for RpmbGetDeviceInfoResponse
Sourceimpl Ord for RpmbGetDeviceInfoResponse
impl Ord for RpmbGetDeviceInfoResponse
Sourcefn cmp(&self, other: &RpmbGetDeviceInfoResponse) -> Ordering
fn cmp(&self, other: &RpmbGetDeviceInfoResponse) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialOrd for RpmbGetDeviceInfoResponse
impl PartialOrd for RpmbGetDeviceInfoResponse
impl Copy for RpmbGetDeviceInfoResponse
impl Eq for RpmbGetDeviceInfoResponse
impl StructuralPartialEq for RpmbGetDeviceInfoResponse