#[repr(C)]pub struct EmmcDeviceInfo {
pub cid: [u8; 16],
pub rpmb_size: u8,
pub reliable_write_sector_count: u8,
}Fields
cid: [u8; 16]rpmb_size: u8reliable_write_sector_count: u8Trait Implementations
Sourceimpl Clone for EmmcDeviceInfo
impl Clone for EmmcDeviceInfo
Sourcefn clone(&self) -> EmmcDeviceInfo
fn clone(&self) -> EmmcDeviceInfo
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for EmmcDeviceInfo
impl Debug for EmmcDeviceInfo
Sourceimpl<'a, ___E> Encode<EmmcDeviceInfo, ___E> for &'a EmmcDeviceInfowhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<EmmcDeviceInfo, ___E> for &'a EmmcDeviceInfowhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<EmmcDeviceInfo>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<EmmcDeviceInfo>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<EmmcDeviceInfo, ___E> for EmmcDeviceInfowhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<EmmcDeviceInfo, ___E> for EmmcDeviceInfowhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<EmmcDeviceInfo, EmmcDeviceInfo>
const COPY_OPTIMIZATION: CopyOptimization<EmmcDeviceInfo, EmmcDeviceInfo>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<EmmcDeviceInfo>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<EmmcDeviceInfo>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<'a, ___E> EncodeOption<Box<'static, EmmcDeviceInfo>, ___E> for &'a EmmcDeviceInfo
impl<'a, ___E> EncodeOption<Box<'static, EmmcDeviceInfo>, ___E> for &'a EmmcDeviceInfo
Sourcefn encode_option(
this: Option<&'a EmmcDeviceInfo>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, EmmcDeviceInfo>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<&'a EmmcDeviceInfo>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, EmmcDeviceInfo>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl<___E> EncodeOption<Box<'static, EmmcDeviceInfo>, ___E> for EmmcDeviceInfo
impl<___E> EncodeOption<Box<'static, EmmcDeviceInfo>, ___E> for EmmcDeviceInfo
Sourcefn encode_option(
this: Option<EmmcDeviceInfo>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, EmmcDeviceInfo>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<EmmcDeviceInfo>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, EmmcDeviceInfo>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
Sourceimpl FromWire<EmmcDeviceInfo> for EmmcDeviceInfo
impl FromWire<EmmcDeviceInfo> for EmmcDeviceInfo
Sourceconst COPY_OPTIMIZATION: CopyOptimization<EmmcDeviceInfo, EmmcDeviceInfo>
const COPY_OPTIMIZATION: CopyOptimization<EmmcDeviceInfo, EmmcDeviceInfo>
Sourcefn from_wire(wire: EmmcDeviceInfo) -> EmmcDeviceInfo
fn from_wire(wire: EmmcDeviceInfo) -> EmmcDeviceInfo
Converts the given owned value to this type.
Sourceimpl FromWireRef<EmmcDeviceInfo> for EmmcDeviceInfo
impl FromWireRef<EmmcDeviceInfo> for EmmcDeviceInfo
Sourcefn from_wire_ref(wire: &EmmcDeviceInfo) -> EmmcDeviceInfo
fn from_wire_ref(wire: &EmmcDeviceInfo) -> EmmcDeviceInfo
Converts the given reference to this type.
Sourceimpl Hash for EmmcDeviceInfo
impl Hash for EmmcDeviceInfo
Sourceimpl Ord for EmmcDeviceInfo
impl Ord for EmmcDeviceInfo
Sourcefn cmp(&self, other: &EmmcDeviceInfo) -> Ordering
fn cmp(&self, other: &EmmcDeviceInfo) -> Ordering
1.21.0 · Sourcefn max(self, other: Self) -> Selfwhere
Self: Sized,
fn max(self, other: Self) -> Selfwhere
Self: Sized,
Compares and returns the maximum of two values. Read more
Sourceimpl PartialEq for EmmcDeviceInfo
impl PartialEq for EmmcDeviceInfo
Sourceimpl PartialOrd for EmmcDeviceInfo
impl PartialOrd for EmmcDeviceInfo
impl Copy for EmmcDeviceInfo
impl Eq for EmmcDeviceInfo
impl StructuralPartialEq for EmmcDeviceInfo