Request

Struct Request 

pub struct Request {
    pub tx_frames: Range,
    pub rx_frames: Option<Box<Range>>,
}
Represents an RPMB operation, which consists of sending one or more frames then receiving zero or more frames. The tx_frames and rx_frames VMOs will be transferred to the protocol implementation, so clients should keep duplicates of them if access is needed after the call to Request(). The request will be aborted as soon as an error is encountered, meaning the read operation will not be performed if the write operation failed. Invalid parameters passed through tx_frames or rx_frames will cause an error to be returned immediately, without either operation having been performed.

Fields

tx_frames: Rangerx_frames: Option<Box<Range>>