#[repr(C)]pub struct EmmcDeviceInfo {
pub cid: [u8; 16],
pub rpmb_size: u8,
pub reliable_write_sector_count: u8,
}Expand description
The wire type corresponding to EmmcDeviceInfo.
Fields
cid: [u8; 16]rpmb_size: u8reliable_write_sector_count: u8Trait Implementations
Sourceimpl Clone for EmmcDeviceInfo
impl Clone for EmmcDeviceInfo
Sourcefn clone(&self) -> EmmcDeviceInfo
fn clone(&self) -> EmmcDeviceInfo
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Constrained for EmmcDeviceInfo
impl Constrained for EmmcDeviceInfo
Sourcetype Constraint = ()
type Constraint = ()
Type of constraint information for this type.
Sourcefn validate(
_: Slot<'_, EmmcDeviceInfo>,
_: <EmmcDeviceInfo as Constrained>::Constraint,
) -> Result<(), ValidationError>
fn validate( _: Slot<'_, EmmcDeviceInfo>, _: <EmmcDeviceInfo as Constrained>::Constraint, ) -> Result<(), ValidationError>
Validate a slot of this type against a constraint. Can be called when
pointers/envelopes are just presence markers.
Sourceimpl Debug for EmmcDeviceInfo
impl Debug for EmmcDeviceInfo
Sourceimpl<___D> Decode<___D> for EmmcDeviceInfowhere
___D: InternalHandleDecoder + ?Sized,
impl<___D> Decode<___D> for EmmcDeviceInfowhere
___D: InternalHandleDecoder + ?Sized,
Sourceimpl<'a, ___E> Encode<EmmcDeviceInfo, ___E> for &'a EmmcDeviceInfowhere
___E: InternalHandleEncoder + ?Sized,
impl<'a, ___E> Encode<EmmcDeviceInfo, ___E> for &'a EmmcDeviceInfowhere
___E: InternalHandleEncoder + ?Sized,
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<EmmcDeviceInfo>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<EmmcDeviceInfo>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl<___E> Encode<EmmcDeviceInfo, ___E> for EmmcDeviceInfowhere
___E: InternalHandleEncoder + ?Sized,
impl<___E> Encode<EmmcDeviceInfo, ___E> for EmmcDeviceInfowhere
___E: InternalHandleEncoder + ?Sized,
Sourceconst COPY_OPTIMIZATION: CopyOptimization<EmmcDeviceInfo, EmmcDeviceInfo>
const COPY_OPTIMIZATION: CopyOptimization<EmmcDeviceInfo, EmmcDeviceInfo>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<EmmcDeviceInfo>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<EmmcDeviceInfo>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
Sourceimpl<___E, T0, T1, T2> Encode<EmmcDeviceInfo, ___E> for EmmcDeviceInfo<T0, T1, T2>
impl<___E, T0, T1, T2> Encode<EmmcDeviceInfo, ___E> for EmmcDeviceInfo<T0, T1, T2>
Sourcefn encode(
self,
encoder_: &mut ___E,
out_: &mut MaybeUninit<EmmcDeviceInfo>,
_: (),
) -> Result<(), EncodeError>
fn encode( self, encoder_: &mut ___E, out_: &mut MaybeUninit<EmmcDeviceInfo>, _: (), ) -> Result<(), EncodeError>
Encodes this value into an encoder and output.
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
const COPY_OPTIMIZATION: CopyOptimization<Self, W> = _
Sourceimpl FromWire<EmmcDeviceInfo> for EmmcDeviceInfo
impl FromWire<EmmcDeviceInfo> for EmmcDeviceInfo
Sourceconst COPY_OPTIMIZATION: CopyOptimization<EmmcDeviceInfo, EmmcDeviceInfo>
const COPY_OPTIMIZATION: CopyOptimization<EmmcDeviceInfo, EmmcDeviceInfo>
Sourcefn from_wire(wire: EmmcDeviceInfo) -> EmmcDeviceInfo
fn from_wire(wire: EmmcDeviceInfo) -> EmmcDeviceInfo
Converts the given owned value to this type.
Sourceimpl FromWireRef<EmmcDeviceInfo> for EmmcDeviceInfo
impl FromWireRef<EmmcDeviceInfo> for EmmcDeviceInfo
Sourcefn from_wire_ref(wire: &EmmcDeviceInfo) -> EmmcDeviceInfo
fn from_wire_ref(wire: &EmmcDeviceInfo) -> EmmcDeviceInfo
Converts the given reference to this type.
Sourceimpl IntoNatural for EmmcDeviceInfo
impl IntoNatural for EmmcDeviceInfo
Sourcetype Natural = EmmcDeviceInfo
type Natural = EmmcDeviceInfo
A good default type for this wire type to convert into.
fn into_natural(self) -> Self::Natural
fn into_natural(self) -> Self::Natural
Converts this type into its natural equivalent.
Sourceimpl Wire for EmmcDeviceInfo
impl Wire for EmmcDeviceInfo
Sourcetype Narrowed<'de> = EmmcDeviceInfo
type Narrowed<'de> = EmmcDeviceInfo
The narrowed wire type, restricted to the
'de lifetime.Sourcefn zero_padding(out_: &mut MaybeUninit<EmmcDeviceInfo>)
fn zero_padding(out_: &mut MaybeUninit<EmmcDeviceInfo>)
Writes zeroes to the padding for this type, if any.