pub struct Request {
pub tx_frames: Range,
pub rx_frames: Option<Box<Range>>,
}Expand description
Represents an RPMB operation, which consists of sending one or more frames then receiving zero or more frames. The tx_frames and rx_frames VMOs will be transferred to the protocol implementation, so clients should keep duplicates of them if access is needed after the call to Request(). The request will be aborted as soon as an error is encountered, meaning the read operation will not be performed if the write operation failed. Invalid parameters passed through tx_frames or rx_frames will cause an error to be returned immediately, without either operation having been performed.
Fields
tx_frames: Rangerx_frames: Option<Box<Range>>Trait Implementations
Sourceimpl<___E> Encode<Request<'static>, ___E> for Requestwhere
___E: InternalHandleEncoder + ?Sized + Encoder + HandleEncoder,
impl<___E> Encode<Request<'static>, ___E> for Requestwhere
___E: InternalHandleEncoder + ?Sized + Encoder + HandleEncoder,
Sourceimpl<___E> EncodeOption<Box<'static, Request<'static>>, ___E> for Request
impl<___E> EncodeOption<Box<'static, Request<'static>>, ___E> for Request
Sourcefn encode_option(
this: Option<Self>,
encoder: &mut ___E,
out: &mut MaybeUninit<Box<'static, Request<'static>>>,
_: (),
) -> Result<(), EncodeError>
fn encode_option( this: Option<Self>, encoder: &mut ___E, out: &mut MaybeUninit<Box<'static, Request<'static>>>, _: (), ) -> Result<(), EncodeError>
Encodes this optional value into an encoder and output.
impl StructuralPartialEq for Request